Dynamic Attributes Package
============

## Description

Adds custom attributes to any Eloquent model by a database key value store instead of database columns.

This enables Events Project Managers / Clients to request additional data to be stored with the models without running repeated migrations.

(Composer package)

Copyright 2015 DRP (UK) Ltd.

### Maintainers

- chris.normansell@drpgroup.com **Lead Developer**

## How to install
### Step #1
Add the repository to your composer.json.
```
{
    "repositories": [
        {
            "type": "composer",
            "url": "http://composer.drp.digital"
        }
    ]
}
```
### Step #2
Require the admin package into your project.
This will install the latest version.
```
composer require drp/dynamic-attributes
```
### Step #3
Add the admin panel service provider to your app config, located in `config/app.php`. I have listed below the Laravel 5.1 and 5.0 ways of adding a service provider.
#### Laravel 5.1
```
Drp\DynamicAttributes\DynamicAttributesServiceProvider::class,
```
#### Laravel 5.0
```
'Drp\DynamicAttributes\DynamicAttributesServiceProvider',
```
### Step #4
Copy over the migrations needed and run them. This will create 2 tables `model_attributes` and `model_attributes_schema`.
```
php artisan vendor:publish
```
```
php artisan migrate
```
## How to use
Confused? Ask one of the maintainers!

On your models extend `drp\DynamicAttributes\DynamicModel`.

This will now have all the functionality needed to have dynamic attributes.

If you want to add/view/edit/remove the schema then use the built in command `php artisan dynamic:schema {className}`.

E.g. `php artisan dynamic:schema \\App\\User`

If you pass the model an attribute that doesn't exist on the table then it will automatically go create a new schema model for you.

This will guide you through the process of changing the dynamic schema of your model.

## Coding Standards

- PHP: [PSR-2](https://github.com/php-fig/fig-standards/blob/master/accepted/PSR-2-coding-style-guide.md)

## Contributing

#### Issues
Here are some top tips for making the issue assignee high five you upon submission:*

- Exception message - Any messages that have been thrown
- Call stack - The calls that were made before the exception was thrown
- Description - Explain what the issue is.
- Steps to reproduce - Detailed instructions to reproduce the issue, preferably in step-by-step format.

**high fives not guaranteed*

##### Branching
Create new branches from the current 'master' branch. When creating a branch make sure you include information that makes it easier to work with on the command line.

{type}/#{num}-{brief-description-of-issue}

e.g.
- fix/#666-delete-the-devil
- feature/#123-make-it-as-easy-as-123

Submit a Merge Request to one of the maintainers and be ready for an exciting code review.
