<?php

namespace Drp\DynamicAttributes;

use Illuminate\Database\Eloquent\Model;

class Attribute extends Model
{
    /**
     * The table associated with the model.
     *
     * @var string
     */
    protected $table = 'model_attributes';

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $fillable = [
        'value', 'model_id', 'schema_id',
    ];

    /**
     * The relations to eager load on every query.
     *
     * @var array
     */
    protected $with = [
        'schema',
    ];

    /**
     * Attribute Schema relationship
     *
     * @return \Illuminate\Database\Eloquent\Relations\HasOne
     */
    public function schema()
    {
        $relationship = $this->hasOne(
            AttributeSchema::class,
            'id',
            'schema_id'
        );

        return $relationship;
    }

    /**
     * Gets the field attribute off the schema.
     *
     * @return string
     */
    public function getFieldAttribute()
    {
        if ($this->schema === null) {
            return null;
        }

        return $this->schema->field;
    }

    /**
    * Gets the field required attribute off the schema.
    *
    * @return string
    */
    public function getFieldRequiredAttribute()
    {
        if ($this->schema === null) {
            return null;
        }

        return $this->schema->required;
    }
}
